{ config, pkgs, modulesPath, lib, ... }:

{
  imports = [
    ./generic.nix
    ../modules/hardware/generic.nix ../modules/hardware/video.nix 
    ../modules/users/fuck-xi.nix
    ../modules/programs/zsh ../modules/programs/tmux ../modules/programs/emacs ../modules/programs/firefox ../modules/programs/gnome-terminal ../modules/programs/gnome
  ];

  nixpkgs.overlays = [
    (import (builtins.fetchGit {
      url = "https://github.com/nix-community/emacs-overlay.git";
      ref = "master";
      rev = "ce0e9482d53d69bedc8416d8a984d00e17607826";
    }))

    # Unstable, NUR, ...
    (import ../overlays/unstable.nix pkgs)
    (import ../overlays/nur.nix pkgs)
    (import ../overlays/custom.nix pkgs)
  ];
  
  environment = {
    systemPackages = with pkgs; [
      emacsPgtkGcc
    ];

    sessionVariables = {
      # Prevent us from having to always type it out
      #NIXOS_CONFIG = "\${HOME}/Development/Personal/nixos-config/hosts/isla.nix";
    };    
  };

  networking = {
    interfaces.enp6s0.useDHCP = false;
    hostName = "isla";
    # Nix otherwise has a conflict with this option
    wireless.enable = lib.mkForce false;

    # Allow scream to connect to this host
    firewall.allowedUDPPorts = [ 4010 ];
  };

  boot = {
    loader = {
      systemd-boot.enable = true;
      efi.canTouchEfiVariables = true;
    };
    extraModprobeConfig = "";
    initrd = {
      availableKernelModules = [ "xhci_pci" "ahci" "usbhid" "sd_mod" "amdgpu" "vendor-reset" ];
      kernelModules = [];
    };
    kernelParams = [];
    kernelModules = [];
    extraModulePackages = [];
    kernelPackages = pkgs.linuxPackages_zen;
  };

  services = {
    emacs.package = pkgs.emacsPgtkGcc;
  };
  
  systemd.services.NetworkManager-wait-online.enable = false;
  
  fileSystems = {
    "/" = {
      device = "/dev/disk/by-label/root";
      fsType = "btrfs";
    };
  };
  swapDevices = [ ];
}
